Case History

## Jammu Wing

## Case Details

Case Type : HCP
Filing Number: 9702/2018Filing Date: 28-12-2018
Registration Number: 58/2018 Registration Date: 29-12-2018
CNR Number: JKHC02-011375-2018

## Case Status

First Hearing Date : 31st December 2018
Decision Date: 24th December 2020
Case Status : CASE DISPOSED
Nature of Disposal: Uncontested--Dismissed
Coram : 1712HON'BLE MR. JUSTICE SANJAY DHAR Bench : Single Bench State : JAMMUKASHMIR District : SRINAGAR Judicial : HABEUS CORPUS PETITION (HCP)Causelist Name : After Notice Short Order : DATE FIXED Not Before Me :

## Petitioner and Advocate

1) ASHRAM HUSSAIN

## Respondent and Advocate

1) STATE TH.HOME DEPTT.AND ORS.

## Subordinate Court Information

Court Number and Name: ---
Case Number and Year: 0
Case Decision Date : : --state:
District:

## IA Details

IA Number | Party | Date of Filing | Next Date | IA Status
--- | --- | --- | --- | ---
IA/1/2018 Classification : | ASHRAM HUSSAIN STATE TH.HOME DEPTT.AND ORS. | 29-12-2018 | 24-12-2020 | Disposed

## History of Case Hearing

Cause List Type | Judge | Business On Date | Hearing Date | Purpose of hearing
--- | --- | --- | --- | ---
| HON'BLE MR. JUSTICE SANJAY DHAR | 24-12-2020 |  | Disposed
|  |  | 31-12-2018 | FOR ADMISSION After Notice
Supplementary-1 | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 31-12-2018 | 17-01-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MRS. JUSTICE SINDHU SHARMA | 17-01-2019 | 29-01-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 29-01-2019 | 26-02-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 26-02-2019 | 03-04-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 03-04-2019 | 26-04-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 26-04-2019 | 06-05-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 06-05-2019 | 08-07-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE ALI MOHAMMAD MAGREY | 08-07-2019 | 05-08-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 05-08-2019 | 11-09-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE RAJESH BINDAL | 11-09-2019 | 14-10-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 14-10-2019 | 04-11-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 04-11-2019 | 04-12-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE RAJESH BINDAL | 04-12-2019 | 27-12-2019 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE ALI MOHAMMAD MAGREY | 27-12-2019 | 28-02-2020 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE SANJEEV KUMAR | 28-02-2020 | 21-04-2020 | SPECIALLY ORDERED CASES
Regular | HON'BLE MR. JUSTICE PUNEET GUPTA | 21-04-2020 | 11-08-2020 | SPECIALLY ORDERED CASES
After Notice | HON'BLE MR. JUSTICE RAJNESH OSWAL | 11-08-2020 | 11-09-2020 | SPECIALLY ORDERED CASES
After Notice | HON'BLE MR. JUSTICE RAJNESH OSWAL | 11-09-2020 | 22-09-2020 | SPECIALLY ORDERED CASES
After Notice | HON'BLE MR. JUSTICE RAJNESH OSWAL | 22-09-2020 | 05-10-2020 | SPECIALLY ORDERED CASES
After Notice | HON'BLE MR. JUSTICE SANJAY DHAR | 05-10-2020 | 19-10-2020 | SPECIALLY ORDERED CASES
After Notice | HON'BLE MR. JUSTICE SANJAY DHAR | 19-10-2020 | 07-12-2020 | SPECIALLY ORDERED CASES
After Notice | HON'BLE MR. JUSTICE SANJAY DHAR | 07-12-2020 | 24-12-2020 | SPECIALLY ORDERED CASES

## Orders

Order Number | Order on | Judge | Order Date | Order Details
1 | HCP/58/2018 | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 26-02-2019 | View
2 | HCP/58/2018 | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 03-04-2019 | View
3 | HCP/58/2018 | HON'BLE MR. JUSTICE ALI MOHAMMAD MAGREY | 08-07-2019 | View
4 | HCP/58/2018 | HON'BLE MR. JUSTICE ALI MOHAMMAD MAGREY | 08-07-2019 | View
5 | HCP/58/2018 | HON'BLE MR. JUSTICE RAJESH BINDAL | 11-09-2019 | View
6 | HCP/58/2018 | HON'BLE MR. JUSTICE DHIRAJ SINGH THAKUR | 14-10-2019 | View
7 | HCP/58/2018 | HON'BLE MR. JUSTICE SANJEEV KUMAR | 28-02-2020 | View
8 | HCP/58/2018 | HON'BLE MR. JUSTICE SANJAY DHAR | 19-10-2020 | View
9 | HCP/58/2018 | HON'BLE MR. JUSTICE SANJAY DHAR | 24-12-2020 | View

## Category Details

Category | SB HABEAS CORPUS PETITION ( 107 )
Sub Category | OTHER MATTERS ( 99 )

## OBJECTION

Sr.No. | Scrutiny Date | OBJECTION | Compliance Date | Receipt Date
1 | 29-12-2018 | All Objections are Complied | -- | --

## Document Details

Sr. No. | Document No. | Date of Receiving | Filed by | Name of Advocate | Document Filed
--- | --- | --- | --- | --- | ---
1 | 1 | 03-05-2019 | STATE TH.HOME DEPTT.AND ORS. | J A KAZMI | VAKALATNAMA
2 | 2 | 14-10-2019 | STATE TH.HOME DEPTT.AND ORS. | J A KAZMI | REPLY
3 | 3 | 11-11-2020 | STATE TH.HOME DEPTT.AND ORS. | ARSHAD MAJID MALIK DY AG | STATUS REPORT